--==========================================================
-- Design units : Three_to_four (Entity, Architecture, Configuration)
--
-- File name    : MinMax_3_to_4.vhd
--
-- Purpose      : Generates 4 conditions out of 3 input signals
--                for the control of the MinMax-Circuit
--
-- Limitations  : - 
--
-- Library      : WORK
--
-- Dependencies : ELEMpack
--
-- Author       : Claus-Juergen Thomas, REFT
--
-- Simulator    : Synopsys V3.1a on SUN SPARCstation 10
--
-----------------------------------------------------------
-- Revision list
-- Version Author Date           Changes
--
--  v1.0   cjt    13.12.95       new
--=========================================================

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE work.ELEMpack.all;
USE work.MinMaxPack.all;

ENTITY Three_to_four IS
  PORT(Clear      : IN std_logic;
       Enable     : IN std_logic;
       Reset      : IN std_logic;
       Condition1 : OUT std_logic;
       Condition2 : OUT std_logic;
       Condition3 : OUT std_logic;
       Condition4 : OUT std_logic);
END Three_to_four;

--===========================ARCHITECTURE=================

ARCHITECTURE Structure OF Three_to_four IS

SIGNAL not_Clear,not_Enable,not_Reset,internal: std_logic;

BEGIN

  Inv_1 : INV
  PORT MAP(Clear,
           not_Clear);

  Inv_2 : INV
  PORT MAP(Reset,
           not_Reset);

  Inv_3 : INV
  PORT MAP(Enable,
           not_Enable);

  And_1 : AND2
  PORT MAP(not_Clear,
           not_Enable,
           Condition2);

  And_2 : AND2
  PORT MAP(not_Clear,
           Enable,
           internal);

  And_3 : AND2
  PORT MAP(internal,
           Reset,
           Condition3);

  And_4 : AND2
  PORT MAP(internal,
           not_Reset,
           Condition4);

  Condition1 <= Clear;

END Structure;

--===========================CONFIGURATION=================

CONFIGURATION Three_to_four_Config OF Three_to_four IS

  FOR structure

    FOR Inv_1 : INV
      USE ENTITY work.INV(Behavior);
    END FOR;
    
    FOR Inv_2 : INV
      USE ENTITY work.INV(Behavior);
    END FOR;
    
    FOR Inv_3 : INV
      USE ENTITY work.INV(Behavior);
    END FOR;
    
    FOR And_1 : AND2
      USE ENTITY work.AND2(Behavior);
    END FOR;
    
    FOR And_2 : AND2
      USE ENTITY work.AND2(Behavior);
    END FOR;
    
    FOR And_3 : AND2
      USE ENTITY work.AND2(Behavior);
    END FOR;
    
    FOR And_4 : AND2
      USE ENTITY work.AND2(Behavior);
    END FOR;

  END FOR;

END Three_to_four_Config;
